summaryrefslogtreecommitdiffstats
path: root/korn/accountmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/accountmanager.h')
-rw-r--r--korn/accountmanager.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/korn/accountmanager.h b/korn/accountmanager.h
index 958e5b57..037887d4 100644
--- a/korn/accountmanager.h
+++ b/korn/accountmanager.h
@@ -19,7 +19,7 @@
#ifndef MK_ACCOUNTMANAGER_H
#define MK_ACCOUNTMANAGER_H
-#include <qobject.h>
+#include <tqobject.h>
class DCOPDrop;
class KornSubjectsDlg;
@@ -42,9 +42,9 @@ class AccountManager : public QObject
{ Q_OBJECT
public:
/**
* Constructor, parameters are directed to QObject.
*/
- AccountManager( QObject * parent = 0, const char * name = 0 );
+ AccountManager( TQObject * parent = 0, const char * name = 0 );
/**
* Destructor
@@ -72,13 +72,13 @@ public:
virtual void writeConfig( KConfig* config, const int index );
/**
* This method makes a QString which can be used for a tooltip.
* In it, all accounts are summed and the number of new messages of
* every account is added.
*
* @return A string that can be used for the Tooltip of the box.
*/
- QString getTooltip() const;
+ TQString getTooltip() const;
protected:
/**
* This function is called when the number of emails has changed.
@@ -93,14 +93,14 @@ protected:
* This functions sets a new Tooltip. Boxes must override this method
* @param tooltip The tooltip to be set.
*/
- virtual void setTooltip( const QString& tooltip ) = 0;
+ virtual void setTooltip( const TQString& tooltip ) = 0;
/**
* This funtion is called if @p command have to be executed.
* For example, if new email has arrived, and the user setuped KOrn
* to execute a command. Boxes must override this function.
*/
- virtual void runCommand( const QString& command ) = 0;
+ virtual void runCommand( const TQString& command ) = 0;
/**
* This function can be called by classes that inherit this class.
@@ -135,17 +135,17 @@ private:
int reset;
};
- QPtrList< KMailDrop > *_kioList;
- QPtrList< DCOPDrop > *_dcopList;
+ TQPtrList< KMailDrop > *_kioList;
+ TQPtrList< DCOPDrop > *_dcopList;
- QMap< KMailDrop*, Dropinfo* > *_dropInfo;
+ TQMap< KMailDrop*, Dropinfo* > *_dropInfo;
static KornSubjectsDlg *_subjectsDlg;
private:
int totalMessages();
bool hasNewMessages();
- void playSound( const QString& );
+ void playSound( const TQString& );
private slots:
void slotChanged( int, KMailDrop* );
void slotValidChanged( bool );
@@ -42,9 +42,9 @@ class AccountManager : public QObject
public:
/**
- * Constructor, parameters are directed to QObject.
+ * Constructor, parameters are directed to TQObject.
*/
@@ -72,13 +72,13 @@ public:
virtual void writeConfig( KConfig* config, const int index );
/**
- * This method makes a QString which can be used for a tooltip.
+ * This method makes a TQString which can be used for a tooltip.
* In it, all accounts are summed and the number of new messages of
* every account is added.